@@ -7,8 +7,13 @@ class ModelArguments:
     """
     Arguments pertaining to which model/config/tokenizer we are going to fine-tune from.
     """
-    model_base_dir: str = field("./models/pretrained",
-                                "the path base dir of models, model_base_dir and model_name decides the final model path")
+    model_base_dir: str = field("",
+                                "The 'model_base_dir' generally is for the finetuned models."
+                                "Generally, the model is loaded from 'model_base_dir' firstly."
+                                " If the model cannot be found, it will be loaded from the model_cache_dir.")
+
+    model_cache_dir: str = field("./models/pretrained",
+                                 "This folder is for the pretrained models downloaded from Internet.")
 
     model_name: str = field("bert-base-chinese", "the name of model: " + str(ALL_TASK_MODEL_PATHS))
 
